import { cdn, upCdn } from '@/services/api';
import { checkData } from '@/services/utils';
import axios from 'axios';
export const img_cdn = 'https://assets.le5lecdn.com';
export const img_upCdn = 'https://drive.le5lecdn.com';

const components = [
  'inputDom',
  'selectDom',
  'menuDom',
  'headMenuDom',
  'sliderVerifyDom',
  'dropdownDom',
  'flvPlayerDom',
  'countdown',
  'swiperDom',
  'threeDSence',
  'rtspPlayerDom',
  'timeline',
  'swiperline',
  'tab',
  'radio',
  'checkbox',
  'calendar',
  'indicator',
  'progress',
  'pagination',
  'steps',
  'notification',
  'list',
  'tree',
  'rockerSwitch',
  'roundSwitch',
  'breadcrumb',
  'transferSwitch',
  'pie3D',
  'hikVideo',
  'thermometer',
  'watermeter',
  'indicatorLight',
  'toggleSwitch',
  'knifeSwitch',
  'compass',
  'thermometer1',
  'airSwitch',
  'waterTank',
];

export const getDownloadList = (meta2dData: any, path: string = 'v') => {
  const lists = new Set();
  //TODO 加一个type区分是数据/还是接口
  //背景图片
  // const meta2dData = meta2d.data();
  let img = meta2dData.bkImage;
  if (img) {
    if (
      img.startsWith('/') ||
      img.startsWith(img_cdn) ||
      img.startsWith(img_upCdn)
    ) {
      let _img = img.replace(img_cdn, '').replace(img_upCdn, '');
      if (_img.startsWith('/v/')) {
        _img = _img.slice(2);
      }
      lists.add({
        url: img,
        path: `/view/projects/${path}` + _img,
      });
    }
  }

  //图片图元(image strokeImage backgroundImage)
  const imageKeys = ['image', 'strokeImage', 'backgroundImage'];
  const images: string[] = [];
  for (const pen of meta2dData.pens) {
    for (const i of imageKeys) {
      const image = pen[i];
      if (image) {
        if (
          image.startsWith('/') ||
          image.startsWith(img_cdn) ||
          image.startsWith(img_upCdn)
        ) {
          // 只考虑相对路径下的 image ，绝对路径图片无需下载
          let _img = image.replace(img_cdn, '').replace(img_upCdn, '');
          if (_img.startsWith('/v/')) {
            _img = _img.slice(2);
          }
          if (!images.includes(image)) {
            // let _img = image.replace(cdn, '').replace(upCdn, '');
            lists.add({
              url: image,
              path: `/view/projects/${path}` + _img,
            });
          }
          pen[i] = `/view/projects/${path}` + _img;
        }
      }
    }
  }

  //其他文件
  const files = [
    '/view/assets/index.js',
    '/view/assets/index.css',
    '/view/css/index.css',

    '/view/js/marked.min.js',
    '/view/js/mycharts.js',
    '/view/js/echarts.min.js',
    '/view/js/lcjs.iife.js',
    '/view/js/highcharts.js',
    '/view/js/highcharts-more.js',
    // '/view/js/2d-components.js',

    '/view/js/r.js',
    '/view/index.html',
    '/view/favicon.ico',
    '/view/view.conf',
    '/view/离线部署包使用说明.pdf',
  ];
  files.forEach((file) => {
    lists.add({
      url: (cdn ? cdn : '') + file,
      path: file,
    });
  });

  //数据
  // const data: any = meta2d.data();
  if (meta2dData._id) delete meta2dData._id;
  if (meta2dData.id) delete meta2dData.id;
  if ((meta2dData as any).image) delete (meta2dData as any).image;
  checkData(meta2dData);
  lists.add({
    data: JSON.stringify(meta2dData)
      .replaceAll(img_cdn, '')
      .replaceAll(img_upCdn, ''),
    path: `/view/projects/${path}/data`,
  });

  return lists;
};

export const getPayList = (meta2dData: any) => {
  const pngs = new Set<string>();
  const jsPens = new Set<string>();
  const iotPens = new Set<string>();
  const svgPens = new Set<string>();
  for (const pen of meta2dData.pens) {
    if (pen.image) {
      if (
        pen.image.startsWith(`${img_cdn}/png/`) ||
        pen.image.startsWith('/png/')
      ) {
        pngs.add(pen.image.replace(img_cdn, ''));
      }
    } else if (pen.subClassName && pen.fullname) {
      jsPens.add(pen.name);
    } else if (components.includes(pen.name)) {
      iotPens.add(pen.name);
    } else if (pen.svgUrl) {
      if (
        pen.svgUrl.startsWith(`${img_cdn}/svg/`) ||
        pen.svgUrl.startsWith('/svg/')
      ) {
        svgPens.add(pen.svgUrl.replace(img_cdn, ''));
      }
    }
  }

  if (![...svgPens].length) {
    //判断是否为老数据
    if (meta2dData.paths) {
      let keys = [];
      for (let key of Object.keys(meta2dData.paths)) {
        let path = meta2dData.paths[key];
        if (
          path.indexOf('-1.18Zm4-1') !== -1 ||
          path.indexOf('-1.19Zm4-1') !== -1 ||
          path.indexOf('2.85ZM') !== -1 ||
          path.indexOf('-1-2.39.3') !== -1
        ) {
          keys.push(keys);
        }
      }
      let flag = meta2dData.pens.some(
        (pen) => pen.name === 'svgPath' && keys.includes(pen.pathId)
      );
      if (flag) {
        svgPens.add('*'); //需要购买所有
      }
    }
  }

  return {
    pngs: [...pngs],
    jsPens: [...jsPens],
    iotPens: [...iotPens],
    svgPens: [...svgPens],
  };
};

//获取已购买
export const getComponentPurchased = async (list: any) => {
  let _list = [];
  list.pngs.forEach((item) => {
    _list.push({
      type: '图片图元',
      name: item,
    });
  });
  list.jsPens.forEach((item) => {
    _list.push({
      type: 'JS线性图元',
      name: item,
    });
  });
  list.iotPens.forEach((item) => {
    _list.push({
      type: '控件',
      name: item,
    });
  });
  if ([...list.svgPens].includes('*')) {
    _list.push({
      type: 'SVG线性图元',
    });
  } else {
    list.svgPens.forEach((item) => {
      _list.push({
        type: 'SVG线性图元',
        name: item,
      });
    });
  }
  const res: any = await axios.post('/api/paid/2d/component', {
    list: _list,
  });

  if (res.error) {
    return [];
  }

  // let purchasedPngs = res.list.filter((item) => list.pngs.has(item));
  // let purchasedJs = res.list.filter((item) => list.jsPens.has(item));
  // let purchasedIot = res.list.filter((item) => list.iotPens.has(item));
  // let purchasedSvg = res.list.filter((item) => list.svgPens.has(item));

  // let price =
  //   ([...list.pngs].length - purchasedPngs.length) * 50 +
  //   ([...list.jsPens].length - purchasedJs.length) * 10 +
  //   ([...list.iotPens].length - purchasedIot.length) * 70+
  //   ([...list.svgPens].length - purchasedSvg.length) * 10;

  return res.list;
};

export const get2dComponentJs = async (names: string[]=components) => {
  let list = [];
  names.forEach((item) => {
    list.push({
      type: '控件',
      name: item,
    });
  });
  const res: any = await axios.post(
    '/api/2d-component.js',
    {
      // list,
    },
    {
      responseType: 'blob',
    }
  );
  return res;
};

export const getTemPngs = async (names: string[]) => {
  const res: any = await axios.post('/api/file/presign', {
    names,
  });
  return res;
};

export const getGoods = async () => {
  const res: any = await axios.get('/api/goods/2d/component/types');
  // console.log("res",res);
  return res;
};

